Enum QueryItem
pub enum QueryItem {
Row(Row),
Metadata(ResultMetadata),
}Expand description
Resulting data from a query.
Variants
Implementations
impl QueryItem
impl QueryItem
pub fn as_metadata(&self) -> Option<&ResultMetadata>
pub fn as_metadata(&self) -> Option<&ResultMetadata>
Returns a reference to the metadata, if the item is of a correct variant.
pub fn as_row(&self) -> Option<&Row>
pub fn as_row(&self) -> Option<&Row>
Returns a reference to the row, if the item is of a correct variant.
pub fn into_metadata(self) -> Option<ResultMetadata>
pub fn into_metadata(self) -> Option<ResultMetadata>
Returns the metadata, if the item is of a correct variant.