Struct ResultMetadata
pub struct ResultMetadata { /* private fields */ }Expand description
Info about the following stream of rows.
Implementations
impl ResultMetadata
impl ResultMetadata
pub fn result_index(&self) -> usize
pub fn result_index(&self) -> usize
The number of the result set, an incrementing value starting from zero, which gives an indication of the position of the result set in the stream.